gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-donau] branch master updated: change submit to batch-submit


From: gnunet
Subject: [taler-donau] branch master updated: change submit to batch-submit
Date: Sun, 09 Jun 2024 00:35:55 +0200

This is an automated email from the git hooks/post-receive script.

lukas-matyja pushed a commit to branch master
in repository donau.

The following commit(s) were added to refs/heads/master by this push:
     new f9c79f2  change submit to batch-submit
f9c79f2 is described below

commit f9c79f277249a41c83508bbcb980772635aa8f31
Author: Matyja Lukas Adam <lukas.matyja@students.bfh.ch>
AuthorDate: Sun Jun 9 00:37:50 2024 +0200

    change submit to batch-submit
---
 src/donau/donau-httpd.c                   | 2 +-
 src/lib/donau_api_batch_submit_receipts.c | 8 ++++----
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/donau/donau-httpd.c b/src/donau/donau-httpd.c
index 43b0c30..857caf5 100644
--- a/src/donau/donau-httpd.c
+++ b/src/donau/donau-httpd.c
@@ -484,7 +484,7 @@ handle_mhd_request (void *cls,
     },
     /* POST submitted receipts */
     {
-      .url = "submit",
+      .url = "batch-submit",
       .method = MHD_HTTP_METHOD_POST,
       .handler.post = &DH_handler_submit_receipts_post
     },
diff --git a/src/lib/donau_api_batch_submit_receipts.c 
b/src/lib/donau_api_batch_submit_receipts.c
index 1647230..268c89a 100644
--- a/src/lib/donau_api_batch_submit_receipts.c
+++ b/src/lib/donau_api_batch_submit_receipts.c
@@ -32,12 +32,12 @@
 
 
 /**
  * Handle for a POST /submit request.
  */
 struct DONAU_DonorReceiptsToStatementHandle
 {
   /**
    * The url for the /submit request.
    */
   char *url;
 
@@ -111,7 +111,7 @@ submit_request_body_to_json (const size_t num_drs,
 
 /**
  * Function called when we're done processing the
  * HTTP POST /submit request.
  *
  * @param cls the `struct KeysRequest`
  * @param response_code HTTP response code, 0 on error
@@ -203,7 +203,7 @@ DONAU_donor_receipts_to_statement (
   birh->cb_cls = cls;
   birh->ctx = ctx;
   birh->url = TALER_url_join (url,
-                              "submit",
+                              "batch-submit",
                               NULL);
   if (NULL == birh->url)
   {
@@ -32,12 +32,12 @@
 
 /**
- * Handle for a POST /submit request.
+ * Handle for a POST /batch-submit request.
  */
 struct DONAU_DonorReceiptsToStatementHandle
@@ -32,12 +32,12 @@
 {
   /**
-   * The url for the /submit request.
+   * The url for the /batch-submit request.
    */
   char *url;
@@ -111,7 +111,7 @@ submit_request_body_to_json (const size_t num_drs,
 /**
  * Function called when we're done processing the
- * HTTP POST /submit request.
+ * HTTP POST /batch-submit request.
  *
  * @param cls the `struct KeysRequest`

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]